# -*- coding: utf-8 -*-
import setuptools

setuptools.setup(
    name="percentage",
    version="0.0.0b0",
    license='BSD',
    author="jeong seojin",
    author_email="seojin123456@naver.com",
    description="Korean High school curriculum(part of percentage) with python code!",
    long_description=open('README.md').read(),
    url="",
    packages=setuptools.find_packages(),
    classifiers=[
        # 패키지에 대한 태그
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent"
    ],
)
